@@ -449,6 +449,7 @@ TimesandSales = """
         amount
         price
         priceUsd
+        indexPrice
         iv
       }
     }
@@ -1228,7 +1229,9 @@ query UtilityRealtimeOptionbook(
             isAtm
             oi
             bestBidPrice
+            bestAskPrice
             usdBid
+            usdAsk
             bidIV
             markIv
             askIv
